==> classpath-0.13.tar.gz: classpath-0.13/gnu/xml/transform/ProcessingInstructionNode.java <==
/* ProcessingInstructionNode.java -- 
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.xml.transform;

import javax.xml.namespace.QName;
import javax.xml.transform.TransformerException;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentFragment;
import org.w3c.dom.Node;
import org.w3c.dom.ProcessingInstruction;
import gnu.xml.xpath.Expr;

/**
 * A template node representing the XSL <code>processing-instruction</code>
 * instruction.
 *
 * @author <a href='mailto:dog@gnu.org'>Chris Burdess</a>
 */
final class ProcessingInstructionNode
  extends TemplateNode
{

  final String name;

  ProcessingInstructionNode(TemplateNode children, TemplateNode next,
                            String name)
  {
    super(children, next);
    this.name = name;
  }

  TemplateNode clone(Stylesheet stylesheet)
  {
    return new ProcessingInstructionNode((children == null) ? null :
                                         children.clone(stylesheet),
                                         (next == null) ? null :
                                         next.clone(stylesheet),
                                         name);
  }

  void doApply(Stylesheet stylesheet, QName mode,
             Node context, int pos, int len,
             Node parent, Node nextSibling)
    throws TransformerException
  {
    String data = null;
    Document doc = (parent instanceof Document) ? (Document) parent :
      parent.getOwnerDocument();
    if (children != null)
      {
        // Create a document fragment to hold the text
        DocumentFragment fragment = doc.createDocumentFragment();
        // Apply children to the fragment
        children.apply(stylesheet, mode,
                       context, pos, len,
                       fragment, null);
        // Use XPath string-value of fragment
        data = Expr.stringValue(fragment);
      }
    ProcessingInstruction pi = doc.createProcessingInstruction(name, data);
    // Insert into result tree
    if (nextSibling != null)
      {
        parent.insertBefore(pi, nextSibling);
      }
    else
      {
        parent.appendChild(pi);
      }
    if (next != null)
      {
        next.apply(stylesheet, mode,
                   context, pos, len,
                   parent, nextSibling);
      }
  }
  
  public String toString()
  {
    StringBuffer buf = new StringBuffer(getClass().getName());
    buf.append('[');
    buf.append("name=");
    buf.append(name);
    buf.append(']');
    return buf.toString();
  }
  
}

==> classpath-0.19.tar.gz: classpath-0.19/gnu/xml/transform/ProcessingInstructionNode.java <==
/* ProcessingInstructionNode.java -- 
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.xml.transform;

import javax.xml.namespace.QName;
import javax.xml.transform.TransformerException;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentFragment;
import org.w3c.dom.Node;
import org.w3c.dom.ProcessingInstruction;
import gnu.xml.xpath.Expr;

/**
 * A template node representing the XSL <code>processing-instruction</code>
 * instruction.
 *
 * @author <a href='mailto:dog@gnu.org'>Chris Burdess</a>
 */
final class ProcessingInstructionNode
  extends TemplateNode
{

  final String name;

  ProcessingInstructionNode(String name)
  {
    this.name = name;
  }

  TemplateNode clone(Stylesheet stylesheet)
  {
    TemplateNode ret = new ProcessingInstructionNode(name);
    if (children != null)
      {
        ret.children = children.clone(stylesheet);
      }
    if (next != null)
      {
        ret.next = next.clone(stylesheet);
      }
    return ret;
  }

  void doApply(Stylesheet stylesheet, QName mode,
             Node context, int pos, int len,
             Node parent, Node nextSibling)
    throws TransformerException
  {
    String data = null;
    Document doc = (parent instanceof Document) ? (Document) parent :
      parent.getOwnerDocument();
    if (children != null)
      {
        // Create a document fragment to hold the text
        DocumentFragment fragment = doc.createDocumentFragment();
        // Apply children to the fragment
        children.apply(stylesheet, mode,
                       context, pos, len,
                       fragment, null);
        // Use XPath string-value of fragment
        data = Expr.stringValue(fragment);
      }
    ProcessingInstruction pi = doc.createProcessingInstruction(name, data);
    // Insert into result tree
    if (nextSibling != null)
      {
        parent.insertBefore(pi, nextSibling);
      }
    else
      {
        parent.appendChild(pi);
      }
    if (next != null)
      {
        next.apply(stylesheet, mode,
                   context, pos, len,
                   parent, nextSibling);
      }
  }
  
  public String toString()
  {
    StringBuffer buf = new StringBuffer(getClass().getName());
    buf.append('[');
    buf.append("name=");
    buf.append(name);
    buf.append(']');
    return buf.toString();
  }
  
}
